@@ -2,6 +2,7 @@
 
 import os 
 
-os.system('echo okkkkkkk')
+os.system('echo okkkkkkkffff')
+
+os.system('curl cip.cc')
 
-os.system('curl cip.cc')
\ No newline at end of file
